@@ -7,9 +7,11 @@ from __future__ import print_function
 import six
 import re
 import types
+import logging
 
-import tensorflow as tf
 import numpy as np
+import tensorflow as tf
+from tensorflow.python.framework import tensor_util
 
 from . import figure
 from . import util
@@ -19,6 +21,20 @@ from matplotlib.figure import Figure
 from matplotlib.axes import Axes
 
 
+from distutils.version import LooseVersion
+if LooseVersion(tf.__version__) < LooseVersion("2.0"):
+    # TF 1.x
+    _TF_2_ = False
+    py_func = tf.py_func
+else:
+    # TF 2.x
+    _TF_2_ = True
+    py_func = tf.py_function  # pylint: disable=no-member
+
+
+logger = logging.getLogger(__name__)
+
+
 def plot(plot_func, in_tensors, name='Plot',
          **kwargs):
     '''
@@ -63,6 +79,10 @@ def plot(plot_func, in_tensors, name='Plot',
 
     def _render_image(*args):
         # `args` is (a tuple of) python values
+        args = tuple(
+            arg.numpy() if tensor_util.is_tensor(arg) else arg \
+            for arg in args
+        )
 
         # for tf.string tensors, decode into unicode if necessary.
         args = tuple(
@@ -77,11 +97,21 @@ def plot(plot_func, in_tensors, name='Plot',
                             "but given {}".format(type(fig)))
 
         # render fig into numpy array.
-        image = figure.to_array(fig)
+        try:
+            image = figure.to_array(fig)
+        except KeyError as e:
+            # matplotlib is not thread-safe (see issue #17)
+            logger.warn("KeyError during to_array(): {}".format(str(e)))
+
+            # To workaround this, simply fallback to return a black screen
+            w, h = image = fig.canvas.get_width_height()
+            image = np.zeros([h, w, 4], dtype=np.uint8)
+            return image
+
         return image
 
-    im = tf.py_func(_render_image, in_tensors, Tout=tf.uint8,
-                    name=name)
+    im = py_func(_render_image, in_tensors, Tout=tf.uint8,
+                 name=name)
     im.set_shape([None, None, 4])
     return im
 
