@@ -14,16 +14,19 @@ import hashlib
 import six
 
 import numpy as np
+import scipy.misc
+
 import tensorflow as tf
 os.environ['TF_CPP_MIN_LOG_LEVEL'] = '3'  # filter out INFO and WARN logs
-tf.logging.set_verbosity(tf.logging.ERROR)
 
 import matplotlib
 matplotlib.rcParams['figure.figsize'] = (2.5, 2.5)
 
 import tfplot.figure
 import tfplot.test_util as test_util
-import scipy.misc
+
+test_util.configure_tf_verbosity()
+
 
 
 
@@ -96,13 +99,13 @@ class TestOps(test_util.TestcaseBase):
         # (a) default execution
         plot_op = tfplot.plot(_overlay_attention, [attention_tensor, image_tensor])
         r = self._execute_plot_op(plot_op, print_image=True)
-        self.assertEquals(test_util.hash_image(r), 'c2d64dedd4aa54218e6df95bfeb03bbc17bd17fa')
+        self.assertEqual(test_util.hash_image(r), 'c2d64dedd4aa54218e6df95bfeb03bbc17bd17fa')
 
         # (b) override cmap and alpha
         plot_op = tfplot.plot(_overlay_attention, [attention_tensor, image_tensor],
                               cmap='gray', alpha=0.8)
         r = self._execute_plot_op(plot_op, print_image=True)
-        self.assertEquals(test_util.hash_image(r), '31c8029aed7bbafe37bb8c451a3220d573d2d0e0')
+        self.assertEqual(test_util.hash_image(r), '31c8029aed7bbafe37bb8c451a3220d573d2d0e0')
 
         # TODO: how to compare images?
 
@@ -133,11 +136,11 @@ class TestOps(test_util.TestcaseBase):
         # make a fake batch
         batch_size = 3
         image_tensor = tf.constant(scipy.misc.face())
-        attention_batch = tf.random_gamma([batch_size, 7, 7], alpha=0.3, seed=42)
+        attention_batch = tf.random.gamma([batch_size, 7, 7], alpha=0.3, seed=42)
         image_batch = tf.tile(tf.expand_dims(image_tensor, 0),
                               [batch_size, 1, 1, 1], name='image_batch') # copy
 
         plot_op = tfplot.plot_many(_overlay_attention, [attention_batch, image_batch])
         r = self._execute_plot_op(plot_op, print_image=False)
         #for i in range(3): imgcat(r[i])
-        self.assertEquals(r.shape, (3, 400, 400, 4))
+        self.assertEqual(r.shape, (3, 400, 400, 4))
